==> pipewire-0.1.6-2-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/annotated_dup.js <==
var annotated_dup =
[
    [ "pw_array", "structpw__array.html", "structpw__array" ],
    [ "pw_client", "classpw__client.html", "classpw__client" ],
    [ "pw_client_events", "structpw__client__events.html", "structpw__client__events" ],
    [ "pw_client_info", "structpw__client__info.html", "structpw__client__info" ],
    [ "pw_client_proxy_events", "structpw__client__proxy__events.html", "structpw__client__proxy__events" ],
    [ "pw_command", "classpw__command.html", "classpw__command" ],
    [ "pw_core", "classpw__core.html", "classpw__core" ],
    [ "pw_core_events", "structpw__core__events.html", "structpw__core__events" ],
    [ "pw_core_info", "structpw__core__info.html", "structpw__core__info" ],
    [ "pw_core_proxy_events", "structpw__core__proxy__events.html", "structpw__core__proxy__events" ],
    [ "pw_core_proxy_methods", "structpw__core__proxy__methods.html", "structpw__core__proxy__methods" ],
    [ "pw_data_loop", "classpw__data__loop.html", "classpw__data__loop" ],
    [ "pw_data_loop_events", "structpw__data__loop__events.html", "structpw__data__loop__events" ],
    [ "pw_factory", "classpw__factory.html", null ],
    [ "pw_factory_implementation", "structpw__factory__implementation.html", "structpw__factory__implementation" ],
    [ "pw_factory_info", "structpw__factory__info.html", "structpw__factory__info" ],
    [ "pw_factory_proxy_events", "structpw__factory__proxy__events.html", "structpw__factory__proxy__events" ],
    [ "pw_global", "classpw__global.html", "classpw__global" ],
    [ "pw_introspect", "classpw__introspect.html", "classpw__introspect" ],
    [ "pw_link", "classpw__link.html", "classpw__link" ],
    [ "pw_link_events", "structpw__link__events.html", "structpw__link__events" ],
    [ "pw_link_info", "structpw__link__info.html", "structpw__link__info" ],
    [ "pw_link_proxy_events", "structpw__link__proxy__events.html", "structpw__link__proxy__events" ],
    [ "pw_log", "classpw__log.html", "classpw__log" ],
    [ "pw_loop", "structpw__loop.html", "structpw__loop" ],
    [ "pw_main_loop", "classpw__main__loop.html", "classpw__main__loop" ],
    [ "pw_main_loop_events", "structpw__main__loop__events.html", "structpw__main__loop__events" ],
    [ "pw_map", "structpw__map.html", "structpw__map" ],
    [ "pw_map_item", "unionpw__map__item.html", "unionpw__map__item" ],
    [ "pw_memblock", "structpw__memblock.html", "structpw__memblock" ],
    [ "pw_module", "classpw__module.html", "classpw__module" ],
    [ "pw_module_events", "structpw__module__events.html", "structpw__module__events" ],
    [ "pw_module_info", "structpw__module__info.html", "structpw__module__info" ],
    [ "pw_module_proxy_events", "structpw__module__proxy__events.html", "structpw__module__proxy__events" ],
    [ "pw_node", "classpw__node.html", "classpw__node" ],
    [ "pw_node_events", "structpw__node__events.html", "structpw__node__events" ],
    [ "pw_node_info", "structpw__node__info.html", "structpw__node__info" ],
    [ "pw_node_proxy_events", "structpw__node__proxy__events.html", "structpw__node__proxy__events" ],
    [ "pw_pipewire", "classpw__pipewire.html", "classpw__pipewire" ],
    [ "pw_port", "classpw__port.html", null ],
    [ "pw_port_events", "structpw__port__events.html", "structpw__port__events" ],
    [ "pw_properties", "structpw__properties.html", "structpw__properties" ],
    [ "pw_protocol", "classpw__protocol.html", null ],
    [ "pw_protocol_client", "structpw__protocol__client.html", "structpw__protocol__client" ],
    [ "pw_protocol_events", "structpw__protocol__events.html", "structpw__protocol__events" ],
    [ "pw_protocol_implementaton", "structpw__protocol__implementaton.html", "structpw__protocol__implementaton" ],
    [ "pw_protocol_marshal", "structpw__protocol__marshal.html", "structpw__protocol__marshal" ],
    [ "pw_protocol_server", "structpw__protocol__server.html", "structpw__protocol__server" ],
    [ "pw_proxy", "classpw__proxy.html", "classpw__proxy" ],
    [ "pw_proxy_events", "structpw__proxy__events.html", "structpw__proxy__events" ],
    [ "pw_registry_proxy_events", "structpw__registry__proxy__events.html", "structpw__registry__proxy__events" ],
    [ "pw_registry_proxy_methods", "structpw__registry__proxy__methods.html", "structpw__registry__proxy__methods" ],
    [ "pw_remote", "classpw__remote.html", "classpw__remote" ],
    [ "pw_remote_events", "structpw__remote__events.html", "structpw__remote__events" ],
    [ "pw_resource", "classpw__resource.html", null ],
    [ "pw_resource_events", "structpw__resource__events.html", "structpw__resource__events" ],
    [ "pw_rtkit", "classpw__rtkit.html", "classpw__rtkit" ],
    [ "pw_stream", "classpw__stream.html", "classpw__stream" ],
    [ "pw_stream_events", "structpw__stream__events.html", "structpw__stream__events" ],
    [ "pw_thread_loop", "classpw__thread__loop.html", "classpw__thread__loop" ],
    [ "pw_thread_loop_events", "structpw__thread__loop__events.html", "structpw__thread__loop__events" ],
    [ "pw_time", "structpw__time.html", "structpw__time" ],
    [ "pw_type", "structpw__type.html", "structpw__type" ],
    [ "pw_utils", "classpw__utils.html", "classpw__utils" ],
    [ "pw_work_queue", "classpw__work__queue.html", "classpw__work__queue" ],
    [ "resource_data", "structresource__data.html", "structresource__data" ]
];

==> pipewire-0.1.8-1-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/annotated_dup.js <==
var annotated_dup =
[
    [ "impl", "structimpl.html", "structimpl" ],
    [ "memblock", "structmemblock.html", "structmemblock" ],
    [ "param_array", "structparam__array.html", "structparam__array" ],
    [ "param_filter", "structparam__filter.html", "structparam__filter" ],
    [ "permission", "structpermission.html", "structpermission" ],
    [ "permissions_update", "structpermissions__update.html", "structpermissions__update" ],
    [ "pw_array", "structpw__array.html", "structpw__array" ],
    [ "pw_client", "classpw__client.html", "classpw__client" ],
    [ "pw_client_events", "structpw__client__events.html", "structpw__client__events" ],
    [ "pw_client_info", "structpw__client__info.html", "structpw__client__info" ],
    [ "pw_client_proxy_events", "structpw__client__proxy__events.html", "structpw__client__proxy__events" ],
    [ "pw_command", "classpw__command.html", "classpw__command" ],
    [ "pw_control", "classpw__control.html", null ],
    [ "pw_control_events", "structpw__control__events.html", "structpw__control__events" ],
    [ "pw_core", "classpw__core.html", "classpw__core" ],
    [ "pw_core_events", "structpw__core__events.html", "structpw__core__events" ],
    [ "pw_core_info", "structpw__core__info.html", "structpw__core__info" ],
    [ "pw_core_proxy_events", "structpw__core__proxy__events.html", "structpw__core__proxy__events" ],
    [ "pw_core_proxy_methods", "structpw__core__proxy__methods.html", "structpw__core__proxy__methods" ],
    [ "pw_data_loop", "classpw__data__loop.html", "classpw__data__loop" ],
    [ "pw_data_loop_events", "structpw__data__loop__events.html", "structpw__data__loop__events" ],
    [ "pw_factory", "classpw__factory.html", null ],
    [ "pw_factory_events", "structpw__factory__events.html", "structpw__factory__events" ],
    [ "pw_factory_implementation", "structpw__factory__implementation.html", "structpw__factory__implementation" ],
    [ "pw_factory_info", "structpw__factory__info.html", "structpw__factory__info" ],
    [ "pw_factory_proxy_events", "structpw__factory__proxy__events.html", "structpw__factory__proxy__events" ],
    [ "pw_global", "classpw__global.html", "classpw__global" ],
    [ "pw_introspect", "classpw__introspect.html", "classpw__introspect" ],
    [ "pw_link", "classpw__link.html", "classpw__link" ],
    [ "pw_link_events", "structpw__link__events.html", "structpw__link__events" ],
    [ "pw_link_info", "structpw__link__info.html", "structpw__link__info" ],
    [ "pw_link_proxy_events", "structpw__link__proxy__events.html", "structpw__link__proxy__events" ],
    [ "pw_log", "classpw__log.html", "classpw__log" ],
    [ "pw_loop", "structpw__loop.html", "structpw__loop" ],
    [ "pw_main_loop", "classpw__main__loop.html", "classpw__main__loop" ],
    [ "pw_main_loop_events", "structpw__main__loop__events.html", "structpw__main__loop__events" ],
    [ "pw_map", "structpw__map.html", "structpw__map" ],
    [ "pw_map_item", "unionpw__map__item.html", "unionpw__map__item" ],
    [ "pw_map_range", "structpw__map__range.html", "structpw__map__range" ],
    [ "pw_memblock", "structpw__memblock.html", "structpw__memblock" ],
    [ "pw_module", "classpw__module.html", "classpw__module" ],
    [ "pw_module_events", "structpw__module__events.html", "structpw__module__events" ],
    [ "pw_module_info", "structpw__module__info.html", "structpw__module__info" ],
    [ "pw_module_proxy_events", "structpw__module__proxy__events.html", "structpw__module__proxy__events" ],
    [ "pw_node", "classpw__node.html", "classpw__node" ],
    [ "pw_node_events", "structpw__node__events.html", "structpw__node__events" ],
    [ "pw_node_info", "structpw__node__info.html", "structpw__node__info" ],
    [ "pw_node_proxy_events", "structpw__node__proxy__events.html", "structpw__node__proxy__events" ],
    [ "pw_pipewire", "classpw__pipewire.html", "classpw__pipewire" ],
    [ "pw_port", "classpw__port.html", null ],
    [ "pw_port_events", "structpw__port__events.html", "structpw__port__events" ],
    [ "pw_properties", "structpw__properties.html", "structpw__properties" ],
    [ "pw_protocol", "classpw__protocol.html", null ],
    [ "pw_protocol_client", "structpw__protocol__client.html", "structpw__protocol__client" ],
    [ "pw_protocol_events", "structpw__protocol__events.html", "structpw__protocol__events" ],
    [ "pw_protocol_implementaton", "structpw__protocol__implementaton.html", "structpw__protocol__implementaton" ],
    [ "pw_protocol_marshal", "structpw__protocol__marshal.html", "structpw__protocol__marshal" ],
    [ "pw_protocol_server", "structpw__protocol__server.html", "structpw__protocol__server" ],
    [ "pw_proxy", "classpw__proxy.html", "classpw__proxy" ],
    [ "pw_proxy_events", "structpw__proxy__events.html", "structpw__proxy__events" ],
    [ "pw_registry_proxy_events", "structpw__registry__proxy__events.html", "structpw__registry__proxy__events" ],
    [ "pw_registry_proxy_methods", "structpw__registry__proxy__methods.html", "structpw__registry__proxy__methods" ],
    [ "pw_remote", "classpw__remote.html", "classpw__remote" ],
    [ "pw_remote_events", "structpw__remote__events.html", "structpw__remote__events" ],
    [ "pw_resource", "classpw__resource.html", null ],
    [ "pw_resource_events", "structpw__resource__events.html", "structpw__resource__events" ],
    [ "pw_rtkit", "classpw__rtkit.html", "classpw__rtkit" ],
    [ "pw_stream", "classpw__stream.html", "classpw__stream" ],
    [ "pw_stream_events", "structpw__stream__events.html", "structpw__stream__events" ],
    [ "pw_thread_loop", "classpw__thread__loop.html", "classpw__thread__loop" ],
    [ "pw_thread_loop_events", "structpw__thread__loop__events.html", "structpw__thread__loop__events" ],
    [ "pw_time", "structpw__time.html", "structpw__time" ],
    [ "pw_type", "structpw__type.html", "structpw__type" ],
    [ "pw_utils", "classpw__utils.html", "classpw__utils" ],
    [ "pw_work_queue", "classpw__work__queue.html", "classpw__work__queue" ],
    [ "resource_data", "structresource__data.html", "structresource__data" ]
];
